@@ -7,10 +7,6 @@ import pandas as pd
 import numpy as np
 import os
 
-OD_CALIBRATION_DATA_FILENAME = "OD_calibration_data.csv"
-PUMP_CALIBRATION_DATA_FILENAME = "PUMP_calibration_data.csv"
-OD_DATA_FILENAME = "OD_data.csv"
-
 class Experiment:
     def __init__(self, name="NewExperiment", connect=True, device_serial="auto",fit_calibration_functions=True):
         """
@@ -25,6 +21,7 @@ class Experiment:
             self.dev = self.connect_device(device_serial=device_serial)
         else:
             self.dev = None
+            self.hub = None
             print("Not connected to device")
         self.Valves = Valves(self)
         self.Photodiodes = Photodiodes(self)
@@ -43,9 +40,9 @@ class Experiment:
 
     def connect_device(self, device_serial="auto"):
         # hub = pm.PMHub.local()
-        hub = pm.PMHub("tcp://localhost:5555")
+        self.hub = pm.PMHub("tcp://localhost:5555")
         if device_serial == "auto":
-            dev = hub.get_devices()[0]
+            dev = self.hub.get_devices()[0]
             self.dev = dev
             return dev
     def test_device(self):
